@@ -9,6 +9,7 @@ import functools
 import logging
 import types
 import werkzeug
+import random
 from opcode import HAVE_ARGUMENT, opmap, opname
 from types import CodeType
 import dateutil
@@ -245,6 +246,13 @@ def _import(name, globals=None, locals=None, fromlist=None, level=-1):
     raise ImportError(name)
 
 
+def match(name, condition_value_list: list, default=None):
+    for condition, value in condition_value_list:
+        if name == condition:
+            return value
+    return default
+
+
 _BUILTINS = {
     '__import__': _import,
     'True': True,
@@ -282,6 +290,8 @@ _BUILTINS = {
     'xrange': range,
     'zip': zip,
     'Exception': Exception,
+    'random': random,
+    'match': match,
 }
 
 
